@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -92,7 +92,7 @@ QTreeWidgetItem* AppDialog::initTopItem(QString text, QPixmap icon)
 
 void AppDialog::loadApps()
 {
-    QTreeWidgetItem* parent;
+    QTreeWidgetItem* parent = NULL;
     foreach (Application app, mw->getApplications())
     {
         switch (app.category)
@@ -153,6 +153,7 @@ void AppDialog::loadApps()
             parent=other;
             break;
         default:
+            parent = NULL;
             break;
         }
 
