@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -24,8 +24,8 @@ ConfigWidget::ConfigWidget ( QString id, ONMainWindow * mw,
 {
 	sessionId=id;
 	mainWindow=mw;
-	miniMode=mw->retMiniMode();	
-	embedMode=embedMode= mw->getEmbedMode();
+	miniMode=mw->retMiniMode();
+	embedMode = mw->getEmbedMode();
 	if(embedMode)
 		sessionId="embedded";
 }
@@ -34,5 +34,3 @@ ConfigWidget::ConfigWidget ( QString id, ONMainWindow * mw,
 ConfigWidget::~ConfigWidget()
 {
 }
-
-
