@@ -684,6 +684,9 @@ private:
     QPushButton* bCancel;
 
 
+    QPushButton *bBrokerLogout;
+
+
     QLabel* selectSessionLabel;
     SessTreeView* sessTv;
 
@@ -796,6 +799,7 @@ private:
     bool useLdap;
     bool showToolBar;
     bool showHaltBtn;
+    bool showBrokerLogoutBtn;
     bool newSession;
     bool runStartApp;
     bool ldapOnly;
@@ -1045,7 +1049,7 @@ private slots:
     void showSessionStatus();
     void slotSshConnectionError ( QString message, QString lastSessionError );
     void slotSshServerAuthError ( int error, QString sshMessage, SshMasterConnection* connection );
-    void slotSshServerAuthPassphrase ( SshMasterConnection* connection, bool verificationCode );
+    void slotSshServerAuthPassphrase ( SshMasterConnection* connection, SshMasterConnection::passphrase_types passphrase_type );
     void slotSshInteractionStart ( SshMasterConnection* connection, QString prompt );
     void slotSshInteractionUpdate ( SshMasterConnection* connection, QString output );
     void slotSshInteractionFinish ( SshMasterConnection* connection);
@@ -1057,6 +1061,7 @@ private slots:
     void slotChangeKbdLayout(const QString& layout);
     void slotSyncX();
     void slotShutdownThinClient();
+    void slotBrokerLogoutButton ();
     void slotReadApplications(bool result, QString output, int pid );
 
 public slots:
@@ -1066,6 +1071,7 @@ public slots:
     void slotDetachProxyWindow();
     void slotActivateWindow();
     void setFocus();
+    void slotEnableBrokerLogoutButton ();
 
 private slots:
     void slotShowPAMSGDialog(bool error, const QString& main_text, const QString& info_text, bool modal);
