@@ -524,12 +524,15 @@ void SshMasterConnection::run()
         x2goDebug << "proxyserver: " << proxyserver << "; proxyport: " << proxyport << "; proxylogin: " << proxylogin;
         sshProxy=new SshMasterConnection (0, proxyserver, proxyport,acceptUnknownServers,
                                           proxylogin, proxypassword, proxykey, proxyautologin, proxyKrbLogin, false);
+
+        qRegisterMetaType<SshMasterConnection::passphrase_types> ("SshMasterConnection::passphrase_types");
+
         connect ( sshProxy, SIGNAL ( connectionOk(QString) ), this, SLOT ( slotSshProxyConnectionOk() ) );
 
         connect ( sshProxy, SIGNAL ( serverAuthError ( int,QString,SshMasterConnection* ) ),this,
                   SLOT ( slotSshProxyServerAuthError ( int,QString, SshMasterConnection* ) ) );
-        connect ( sshProxy, SIGNAL ( needPassPhrase(SshMasterConnection*, bool)),this,
-                  SIGNAL ( needPassPhrase(SshMasterConnection*, bool)) );
+        connect ( sshProxy, SIGNAL ( needPassPhrase(SshMasterConnection*, SshMasterConnection::passphrase_types)),this,
+                  SIGNAL ( needPassPhrase(SshMasterConnection*, SshMasterConnection::passphrase_types)) );
         connect ( sshProxy, SIGNAL ( serverAuthAborted()),this,
                   SLOT ( slotSshProxyServerAuthAborted()) );
         connect ( sshProxy, SIGNAL ( userAuthError ( QString ) ),this,SLOT ( slotSshProxyUserAuthError ( QString ) ) );
@@ -1180,7 +1183,7 @@ bool SshMasterConnection::userChallengeAuth()
                     if (need_to_display_auth_code_prompt) {
                       emit needChallengeResponse(this, pr);
                     } else {
-                      emit needPassPhrase(this, true);
+                      emit needPassPhrase(this, PASSPHRASE_CHALLENGE);
                     }
                     for(;;)
                     {
@@ -1250,42 +1253,65 @@ bool SshMasterConnection::userAuthWithPass()
 
     int method = ssh_userauth_list(my_ssh_session, NULL);
 
-    if (method& SSH_AUTH_METHOD_INTERACTIVE)
-    {
-#ifdef DEBUG
-        x2goDebug<<"Challenge authentication requested."<<endl;
-#endif
-        challengeAuthPasswordAccepted=false;
-        ret = userChallengeAuth();
+    if (method & SSH_AUTH_METHOD_INTERACTIVE) {
+        x2goDebug << "Challenge authentication requested." << endl;
+
+        challengeAuthPasswordAccepted = false;
+        ret = userChallengeAuth ();
+
+        if (!ret) {
+            x2goDebug << "Challenge authentication failed." << endl;
+        }
     }
 
     if (!ret) {
-        x2goDebug << "Challenge authentication failed. Trying password mechanism if available." << endl;
+        x2goDebug << "Trying password mechanism if available." << endl;
     }
 
-    if ((!ret) && (method & SSH_AUTH_METHOD_PASSWORD))
-    {
-        if (!ret) {
-            x2goDebug << "Password mechanism available. Continuing." << endl;
-        }
+    if ((!ret) && (method & SSH_AUTH_METHOD_PASSWORD)) {
+        x2goDebug << "Password mechanism available. Continuing." << endl;
 
-#ifdef DEBUG
-        x2goDebug<<"Password authentication requested."<<endl;
-#endif
-        int rc = ssh_userauth_password ( my_ssh_session, NULL, pass.toLatin1() );
+        QString auth_password = pass;
+
+        if (auth_password.isEmpty ()) {
+            keyPhraseReady = false;
+            emit needPassPhrase (this, PASSPHRASE_PASSWORD);
+
+            for (bool ready = false; !ready;) {
+                this->usleep (200);
+
+                keyPhraseMutex.lock ();
+                ready = keyPhraseReady;
+                keyPhraseMutex.unlock ();
+            }
+
+            if (keyPhrase.isNull ()) {
+                authErrors << "No password provided.";
+                return (ret);
+            }
+            else {
+                auth_password = keyPhrase;
+            }
+        }
+        int rc = ssh_userauth_password (my_ssh_session, NULL, auth_password.toLatin1 ());
         if ( rc != SSH_AUTH_SUCCESS )
         {
             QString err=ssh_get_error ( my_ssh_session );
             authErrors<<err;
-#ifdef DEBUG
-            x2goDebug<<"userAuthWithPass failed:" <<err<<endl;
-#endif
+            x2goDebug << "Password authentication failed: " << err << endl;
         }
         else {
             ret = true;
         }
     }
 
+    if ((!ret) && (method & ~SSH_AUTH_METHOD_PASSWORD)) {
+        /* In case password auth is disabled, make sure the error message is not empty. */
+        QString err = ssh_get_error (my_ssh_session);
+        authErrors << err;
+        x2goDebug << "Password authentication not available: " << err << endl;
+    }
+
     return (ret);
 }
 
@@ -1296,8 +1322,14 @@ bool SshMasterConnection::userAuthAuto()
     int i=0;
     while(rc != SSH_AUTH_SUCCESS)
     {
+        if (SSH_AUTH_DENIED == rc) {
+          /* No need to continue, all keys have been rejected by the server. */
+          break;
+        }
+
+        /* This section should only be executed if rc is SSH_AUTH_ERROR. */
         keyPhraseReady=false;
-        emit needPassPhrase(this, false);
+        emit needPassPhrase(this, PASSPHRASE_PRIVKEY);
         for(;;)
         {
             bool ready=false;
@@ -1323,7 +1355,7 @@ bool SshMasterConnection::userAuthAuto()
         QString err=ssh_get_error ( my_ssh_session );
         authErrors<<err;
 #ifdef DEBUG
-        x2goDebug<<"userAuthAuto failed:" <<err<<endl;
+        x2goDebug << "userAuthAuto failed:" << err << " (code " << rc << ")" << endl;
 #endif
         return false;
     }
@@ -1407,7 +1439,7 @@ bool SshMasterConnection::userAuthWithKey()
 #endif
     {
         keyPhraseReady=false;
-        emit needPassPhrase(this, false);
+        emit needPassPhrase(this, PASSPHRASE_PRIVKEY);
         for(;;)
         {
             bool ready=false;
