@@ -138,7 +138,7 @@ void SshProcess::tunnelLoop()
     setsockopt(serverSocket, IPPROTO_TCP, TCP_NODELAY,&y, sizeof(int));
 
     address.sin_family=AF_INET;
-    address.sin_addr.s_addr=INADDR_ANY;
+    address.sin_addr.s_addr=htonl(INADDR_LOOPBACK);
     address.sin_port=htons(localPort);
     if (bind(serverSocket,(struct sockaddr*) &address,sizeof(address))!=0)
     {
@@ -188,7 +188,7 @@ void SshProcess::rmPuttyReg(QString uuidStr)
 }
 #endif
 
-void SshProcess::startNormal(const QString& cmd)
+void SshProcess::startNormal(const QString& cmd, bool overridePath)
 {
     QUuid uuid = QUuid::createUuid();
     QString uuidStr = uuid.toString().mid(1, 36).toLower();
@@ -198,9 +198,18 @@ void SshProcess::startNormal(const QString& cmd)
 // ONLY UNCOMMENT FOR TESTING, MIGHT REVEAL PASSWORD WHEN command=RDP
     x2goDebug<<"Executing remote command via SshProcess object "<<pid<<": "<<cmd;
 // #endif
+    QString pathString;
+    if (overridePath)
+    {
+        pathString = "export PATH=\"/usr/local/bin:/usr/bin:/bin\";";
+    }
+    else
+    {
+        pathString= "";
+    }
     if(!masterCon->useKerberos())
     {
-        QString shcmd = "bash -l -c 'echo \"X2GODATABEGIN:" + uuidStr + "\"; export PATH=\"/usr/local/bin:/usr/bin:/bin\"; export TERM=\"dumb\"; "+cmd+"; echo \"X2GODATAEND:" + uuidStr + "\";'";
+        QString shcmd = "bash -l -c 'echo \"X2GODATABEGIN:" + uuidStr + "\"; " + pathString + "export TERM=\"dumb\"; "+cmd+"; echo \"X2GODATAEND:" + uuidStr + "\";'";
         x2goDebug << "this="<<this<<" Running masterCon->addChannelConnection(this, '" << uuidStr << "', '" << shcmd.left (200) << "');";
         masterCon->addChannelConnection(this, uuidStr, shcmd);
         connect(masterCon,SIGNAL(stdOut(SshProcess*,QByteArray)),this,SLOT(slotStdOut(SshProcess*,QByteArray)));
@@ -222,7 +231,7 @@ void SshProcess::startNormal(const QString& cmd)
          * as there is no preceding "outer double quote" the whole argument
          * is wrapped in.
          */
-        shcmd = "bash -l -c 'echo \"X2GODATABEGIN:" + uuidStr + "\"; export PATH=\"/usr/local/bin:/usr/bin:/bin\"; export TERM=\"dumb\"; "+cmd+"; echo \"X2GODATAEND:" + uuidStr + "\";'";
+        shcmd = "bash -l -c 'echo \"X2GODATABEGIN:" + uuidStr + "\";" + pathString + "export TERM=\"dumb\"; "+cmd+"; echo \"X2GODATAEND:" + uuidStr + "\";'";
 
         proc=new QProcess(this);
         QString local_cmd = "";
